@@ -1,7 +1,7 @@
 // qmidinet.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -36,7 +36,7 @@
 
 // Constructor.
 qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
-	: QObject(NULL), m_pApp(NULL), m_pIcon(NULL)
+	: QObject(nullptr), m_pApp(nullptr), m_pIcon(nullptr)
 	#ifdef CONFIG_ALSA_MIDI	
 		, m_alsa(this)
 	#endif
@@ -46,15 +46,26 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 		, m_udpd(this)
 {
 	if (bGUI) {
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+		QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+	#endif
 		QApplication *pApp = new QApplication(argc, argv);
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
+		pApp->setApplicationDisplayName(QMIDINET_TITLE);
+		//	QMIDINET_TITLE " - " + QObject::tr(QMIDINET_SUBTITLE));
+	#endif
 		pApp->setQuitOnLastWindowClosed(false);
 		m_pApp  = pApp;
 		m_pIcon = new qmidinetSystemTrayIcon(this);
 	} else {
 		m_pApp  = new QCoreApplication(argc, argv);
-		m_pIcon = NULL;
+		m_pIcon = nullptr;
 	}
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
+	m_pApp->setApplicationName(QMIDINET_TITLE);
+#endif
+
 #ifdef CONFIG_ALSA_MIDI
 	QObject::connect(
 		&m_udpd, SIGNAL(received(const QByteArray&, int)),
@@ -106,7 +117,7 @@ qmidinetApplication::~qmidinetApplication (void)
 bool qmidinetApplication::setup (void)
 {
 	qmidinetOptions *pOptions = qmidinetOptions::getInstance();
-	if (pOptions == NULL)
+	if (pOptions == nullptr)
 		return false;
 
 	m_udpd.close();
@@ -120,7 +131,7 @@ bool qmidinetApplication::setup (void)
 #ifdef CONFIG_ALSA_MIDI
 	if (pOptions->bAlsaMidi
 		&& !m_alsa.open(QMIDINET_TITLE, pOptions->iNumPorts)) {
-		message(tr("ALSA MIDI Inferface Error - %1").arg(QMIDINET_TITLE),
+		message(tr("ALSA MIDI Inferface Error"),
 			tr("The ALSA MIDI interface could not be established.\n\n"
 			"Please, make sure you have a ALSA MIDI sub-system working "
 			"correctly and try again."));
@@ -134,7 +145,7 @@ bool qmidinetApplication::setup (void)
 	#ifdef CONFIG_ALSA_MIDI
 		m_alsa.close();
 	#endif
-		message(tr("JACK MIDI Inferface Error - %1").arg(QMIDINET_TITLE),
+		message(tr("JACK MIDI Inferface Error"),
 			tr("The JACK MIDI interface could not be established.\n\n"
 			"Please, make sure you have a JACK MIDI sub-system working "
 			"correctly and try again."));
@@ -153,7 +164,7 @@ bool qmidinetApplication::setup (void)
 	#ifdef CONFIG_JACK_MIDI
 		m_jack.close();
 	#endif
-		message(tr("Network Inferface Error - %1").arg(QMIDINET_TITLE),
+		message(tr("Network Inferface Error"),
 			tr("The network interface could not be established.\n\n"
 			"Please, make sure you have an on-line network connection "
 			"and try again."));
@@ -191,7 +202,7 @@ void qmidinetApplication::shutdown (void)
 {
 	m_jack.close();
 
-	message(tr("JACK MIDI Inferface Error - %1").arg(QMIDINET_TITLE),
+	message(tr("JACK MIDI Inferface Error"),
 		tr("The JACK MIDI interface has been shutdown.\n\n"
 		"Please, make sure you reactivate the JACK MIDI sub-system "
 		"and try again."));
@@ -278,7 +289,7 @@ void qmidinetSystemTrayIcon::show ( bool bSetup )
 // Options dialog.
 void qmidinetSystemTrayIcon::options (void)
 {
-	if (qmidinetOptionsForm(NULL).exec())
+	if (qmidinetOptionsForm(nullptr).exec())
 		reset();
 }
 
@@ -328,7 +339,7 @@ void qmidinetSystemTrayIcon::about (void)
 
 	QMessageBox abox;
 	abox.setWindowIcon(QSystemTrayIcon::icon());
-	abox.setWindowTitle(tr("About %1").arg(QMIDINET_TITLE));
+	abox.setWindowTitle(tr("About"));
 	abox.setIconPixmap(QPixmap(":/images/qmidinet.png"));
 	abox.setText(sText);
 	abox.exec();
@@ -342,7 +353,7 @@ void qmidinetSystemTrayIcon::message (
 	if (QSystemTrayIcon::supportsMessages()) {
 		QSystemTrayIcon::showMessage(sTitle, sText, QSystemTrayIcon::Critical);
 	} else {
-		QMessageBox::critical(NULL, sTitle, sText);
+		QMessageBox::critical(nullptr, sTitle, sText);
 	}
 }
 
