@@ -1,7 +1,7 @@
 // qmidinetJackMidiDevice.h
 //
 /****************************************************************************
-   Copyright (C) 2010-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ class qmidinetJackMidiDevice : public QObject
 public:
 
 	// Constructor.
-	qmidinetJackMidiDevice(QObject *pParent = NULL);
+	qmidinetJackMidiDevice(QObject *pParent = nullptr);
 
 	// Destructor.
 	~qmidinetJackMidiDevice();
