@@ -1,7 +1,7 @@
 // qmidinetOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2010-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,9 +25,10 @@
 #include <QSettings>
 #include <QStringList>
 
-
 // Some hard-coded default options....
-#define QMIDINET_UDP_ADDR "225.0.0.37"
+#define QMIDINET_UDP_IPV4_ADDR "225.0.0.37"
+#define QMIDINET_UDP_IPV6_ADDR "ff12::37"
+
 #define QMIDINET_UDP_PORT  21928
 
 
