@@ -1,7 +1,7 @@
 // qmidinetOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,6 +26,10 @@
 
 #include <QMessageBox>
 
+#if defined(CONFIG_IPV6)
+#include <QNetworkInterface>
+#endif
+
 
 //----------------------------------------------------------------------------
 // qmidinetOptionsForm -- UI wrapper form.
@@ -38,16 +42,30 @@ qmidinetOptionsForm::qmidinetOptionsForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	// Initialize the dialog widgets with deafult settings...
+	// Initialize the dialog widgets with default settings...
 	m_sDefInterface = tr("(Any)");
 	m_ui.InterfaceComboBox->clear();
 	m_ui.InterfaceComboBox->addItem(m_sDefInterface);
+#if defined(CONFIG_IPV6)
+	foreach (const QNetworkInterface& iface, QNetworkInterface::allInterfaces()) {
+		if (iface.isValid() &&
+			iface.flags().testFlag(QNetworkInterface::CanMulticast) &&
+			iface.flags().testFlag(QNetworkInterface::IsUp) &&
+			iface.flags().testFlag(QNetworkInterface::IsRunning) &&
+			!iface.flags().testFlag(QNetworkInterface::IsLoopBack)) {
+			m_ui.InterfaceComboBox->addItem(iface.name());
+		}
+	}
+#else
 	m_ui.InterfaceComboBox->addItem("wlan0");
 	m_ui.InterfaceComboBox->addItem("eth0");
+#endif
 
 	m_ui.UdpAddrComboBox->clear();
-	m_ui.UdpAddrComboBox->addItem(QMIDINET_UDP_ADDR);
-
+	m_ui.UdpAddrComboBox->addItem(QMIDINET_UDP_IPV4_ADDR);
+#if defined(CONFIG_IPV6)
+	m_ui.UdpAddrComboBox->addItem(QMIDINET_UDP_IPV6_ADDR);
+#endif
 	m_ui.UdpPortSpinBox->setValue(QMIDINET_UDP_PORT);
 
 	// Populate dialog widgets with current settings...
@@ -180,7 +198,16 @@ void qmidinetOptionsForm::buttonClick ( QAbstractButton *pButton )
 		= m_ui.DialogButtonBox->buttonRole(pButton);
 	if (buttonRole == QDialogButtonBox::ResetRole) {
 		m_ui.InterfaceComboBox->setCurrentIndex(0);
-		m_ui.UdpAddrComboBox->setCurrentIndex(0);
+	#if defined(CONFIG_IPV6)
+		const QString& sUdpAddr
+			= m_ui.UdpAddrComboBox->currentText();
+		QHostAddress addr;
+		if (addr.setAddress(sUdpAddr) &&
+			addr.protocol() == QAbstractSocket::IPv6Protocol)
+			m_ui.UdpAddrComboBox->setEditText(QMIDINET_UDP_IPV6_ADDR);
+		else
+	#endif
+			m_ui.UdpAddrComboBox->setEditText(QMIDINET_UDP_IPV4_ADDR);
 		m_ui.UdpPortSpinBox->setValue(QMIDINET_UDP_PORT);
 	}
 }
