@@ -1,7 +1,7 @@
 // qmidinetUdpDevice.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,9 +19,15 @@
 
 *****************************************************************************/
 
-#include "qmidinetAbout.h"
 #include "qmidinetUdpDevice.h"
 
+#if defined(CONFIG_IPV6)
+
+#include <QNetworkInterface>
+#include <QByteArray>
+
+#else
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -32,6 +38,7 @@ typedef int socklen_t;
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
+#include <sys/select.h>
 inline void closesocket(int s) { ::close(s); }
 #endif
 
@@ -112,7 +119,7 @@ void qmidinetUdpDeviceThread::run (void)
 		tv.tv_sec  = 1;
 		tv.tv_usec = 0;
 
-		int s = ::select(fdmax + 1, &fds, NULL, NULL, &tv);
+		int s = ::select(fdmax + 1, &fds, nullptr, nullptr, &tv);
 		if (s < 0) {
 			::perror("select");
 			break;
@@ -141,21 +148,31 @@ void qmidinetUdpDeviceThread::run (void)
 	}
 }
 
+#endif	// !CONFIG_IPV6
+
 
 //----------------------------------------------------------------------------
 // qmidinetUdpDevice -- Network interface device (UDP/IP).
 //
 
-qmidinetUdpDevice *qmidinetUdpDevice::g_pDevice = NULL;
+qmidinetUdpDevice *qmidinetUdpDevice::g_pDevice = nullptr;
 
 // Constructor.
 qmidinetUdpDevice::qmidinetUdpDevice ( QObject *pParent )
 	: QObject(pParent), m_nports(0),
-		m_sockin(NULL), m_sockout(NULL), m_addrout(NULL), m_pRecvThread(NULL)
+		m_sockin(nullptr), m_sockout(nullptr)
+	#if defined(CONFIG_IPV6)
+		, m_udpport(nullptr)
+	#else
+		, m_addrout(nullptr)
+		, m_pRecvThread(nullptr)
+	#endif	// !CONFIG_IPV6
 {
+#if !defined(CONFIG_IPV6)
 #if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 	WSAStartup(MAKEWORD(1, 1), &g_wsaData);
 #endif
+#endif	// !CONFIG_IPV6
 
 	g_pDevice = this;
 }
@@ -165,11 +182,13 @@ qmidinetUdpDevice::~qmidinetUdpDevice (void)
 {
 	close();
 
-	g_pDevice = NULL;
+	g_pDevice = nullptr;
 
+#if !defined(CONFIG_IPV6)
 #if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 	WSACleanup();
 #endif
+#endif	// !CONFIG_IPV6
 }
 
 
@@ -187,6 +206,99 @@ bool qmidinetUdpDevice::open ( const QString& sInterface,
 	// Close if already open.
 	close();
 
+#if defined(CONFIG_IPV6)
+
+	// Setup host address for udp multicast...
+	m_udpaddr.setAddress(sUdpAddr);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+	// Check whether is real for udp multicast...
+	if (!m_udpaddr.isMulticast()) {
+		qWarning() << "open(udpaddr):" << sUdpAddr
+			<< "not an udp multicast address";
+		return false;
+	}
+#endif
+	// Check whether protocol is IPv4 or IPv6...
+	const bool ipv6_protocol
+		= (m_udpaddr.protocol() != QAbstractSocket::IPv4Protocol);
+
+	// Setup network interface...
+	QNetworkInterface iface;
+	if (!sInterface.isEmpty())
+		iface = QNetworkInterface::interfaceFromName(sInterface);
+
+	// Set the number of ports.
+	m_nports = iNumPorts;
+
+	// Allocate sockets and addresses...
+	int i;
+
+	m_sockin  = new QUdpSocket * [m_nports];
+	m_sockout = new QUdpSocket * [m_nports];
+
+	m_udpport = new int [m_nports];
+
+	for (i = 0; i < m_nports; ++i) {
+		m_sockin[i]  = new QUdpSocket();
+		m_sockout[i] = new QUdpSocket();
+		m_udpport[i] = iUdpPort + i;
+	}
+
+	// Setup sockets and addreses...
+	//
+	for (i = 0; i < m_nports; ++i) {
+		// Bind input socket...
+		if (!m_sockin[i]->bind(ipv6_protocol
+				? QHostAddress::AnyIPv6
+				: QHostAddress::AnyIPv4,
+				iUdpPort + i, QUdpSocket::ShareAddress)) {
+			qWarning() << "open(sockin):" << i
+				<< "udp socket error"
+				<< m_sockin[i]->error()
+				<< m_sockin[i]->errorString();
+			return false;
+		}
+	#if defined(Q_OS_WIN)
+		m_sockin[i]->setSocketOption(
+			QAbstractSocket::MulticastLoopbackOption, 0);
+	#endif
+		bool joined = false;
+		if (iface.isValid())
+			joined = m_sockin[i]->joinMulticastGroup(m_udpaddr, iface);
+		else
+			joined = m_sockin[i]->joinMulticastGroup(m_udpaddr);
+		if (!joined) {
+			qWarning() << "open(sockin):" << i
+				<< "udp socket error"
+				<< m_sockin[i]->error()
+				<< m_sockin[i]->errorString();
+		}
+		QObject::connect(m_sockin[i],
+			SIGNAL(readyRead()),
+			SLOT(readPendingDatagrams()));
+		// Bind output socket...
+		if (!m_sockout[i]->bind(ipv6_protocol
+				? QHostAddress::AnyIPv6
+				: QHostAddress::AnyIPv4,
+				m_sockout[i]->localPort())) {
+			qWarning() << "open(sockout):" << i
+				<< "udp socket error"
+				<< m_sockout[i]->error()
+				<< m_sockout[i]->errorString();
+			return false;
+		}
+		m_sockout[i]->setSocketOption(
+			QAbstractSocket::MulticastTtlOption, 1);
+	#if defined(Q_OS_UNIX)
+		m_sockout[i]->setSocketOption(
+			QAbstractSocket::MulticastLoopbackOption, 0);
+	#endif
+		if (iface.isValid())
+			m_sockout[i]->setMulticastInterface(iface);
+	}
+
+#else
+
 	// Setup network protocol...
 	int i, protonum = 0;
 #if 0
@@ -196,12 +308,12 @@ bool qmidinetUdpDevice::open ( const QString& sInterface,
 #endif
 
 	// Stable interface name...
-	const char *ifname = NULL;
+	const char *ifname = nullptr;
 	const QByteArray aInterface = sInterface.toLocal8Bit();
 	if (!aInterface.isEmpty())
 		ifname = aInterface.constData();
 
-	const char *udp_addr = NULL;
+	const char *udp_addr = nullptr;
 	const QByteArray aUdpAddr = sUdpAddr.toLocal8Bit();
 	if (!aUdpAddr.isEmpty())
 		udp_addr = aUdpAddr.constData();
@@ -348,6 +460,8 @@ bool qmidinetUdpDevice::open ( const QString& sInterface,
 	m_pRecvThread = new qmidinetUdpDeviceThread(m_sockin, m_nports);
 	m_pRecvThread->start();
 
+#endif	// !CONFIG_IPV6
+
 	// Done.
 	return true;
 }
@@ -356,13 +470,42 @@ bool qmidinetUdpDevice::open ( const QString& sInterface,
 // Device termination method.
 void qmidinetUdpDevice::close (void)
 {
+#if defined(CONFIG_IPV6)
+
+	if (m_sockin) {
+		for (int i = 0; i < m_nports; ++i) {
+			if (m_sockin[i])
+				delete m_sockin[i];
+		}
+		delete [] m_sockin;
+		m_sockin = nullptr;
+	}
+
+	if (m_sockout) {
+		for (int i = 0; i < m_nports; ++i) {
+			if (m_sockout[i])
+				delete m_sockout[i];
+		}
+		delete [] m_sockout;
+		m_sockout = nullptr;
+	}
+
+	m_udpaddr.clear();
+
+	if (m_udpport) {
+		delete [] m_udpport;
+		m_udpport = nullptr;
+	}
+
+#else
+
 	if (m_sockin) {
 		for (int i = 0; i < m_nports; ++i) {
 			if (m_sockin[i] >= 0)
 				::closesocket(m_sockin[i]);
 		}
 		delete [] m_sockin;
-		m_sockin = NULL;
+		m_sockin = nullptr;
 	}
 
 	if (m_sockout) {
@@ -371,12 +514,12 @@ void qmidinetUdpDevice::close (void)
 				::closesocket(m_sockout[i]);
 		}
 		delete [] m_sockout;
-		m_sockout = NULL;
+		m_sockout = nullptr;
 	}
 
 	if (m_addrout) {
 		delete [] m_addrout;
-		m_addrout = NULL;
+		m_addrout = nullptr;
 	}
 
 	if (m_pRecvThread) {
@@ -386,9 +529,11 @@ void qmidinetUdpDevice::close (void)
 			m_pRecvThread->wait(1200); // Timeout>1sec.
 		}
 		delete m_pRecvThread;
-		m_pRecvThread = NULL;
+		m_pRecvThread = nullptr;
 	}
 
+#endif	// !CONFIG_IPV6
+
 	m_nports = 0;
 }
 
@@ -400,7 +545,33 @@ bool qmidinetUdpDevice::sendData (
 	if (port < 0 || port >= m_nports)
 		return false;
 
-	if (m_sockout == NULL)
+#if defined(CONFIG_IPV6)
+
+	if (m_sockout == nullptr)
+		return false;
+	if (m_sockout[port] == nullptr)
+		return false;
+
+	if (!m_sockout[port]->isValid()
+		|| m_sockout[port]->state() != QAbstractSocket::BoundState) {
+		qWarning() << "sendData(sockout):" << port
+			<< "udp socket has invalid state"
+			<< m_sockout[port]->state();
+		return false;
+	}
+
+	QByteArray datagram((const char *) data, len);
+	if (m_sockout[port]->writeDatagram(datagram, m_udpaddr, m_udpport[port]) < len) {
+		qWarning() << "sendData(sockout):" << port
+			<< "udp socket error"
+			<< m_sockout[port]->error() << " "
+			<< m_sockout[port]->errorString();
+		return false;
+	}
+
+#else
+
+	if (m_sockout == nullptr)
 		return false;
 	if (m_sockout[port] < 0)
 		return false;
@@ -412,6 +583,8 @@ bool qmidinetUdpDevice::sendData (
 		return false;
 	}
 
+#endif	// !CONFIG_IPV6
+
 	return true;
 }
 
@@ -430,6 +603,30 @@ void qmidinetUdpDevice::receive ( const QByteArray& data, int port )
 }
 
 
+#if defined(CONFIG_IPV6)
+
+// Process incoming datagrams.
+void qmidinetUdpDevice::readPendingDatagrams (void)
+{
+	if (m_sockin == nullptr)
+		return;
+
+	for (int i = 0; i < m_nports; ++i) {
+		while (m_sockin[i] && m_sockin[i]->hasPendingDatagrams()) {
+			QByteArray datagram;
+			int nread = m_sockin[i]->pendingDatagramSize();
+			datagram.resize(nread);
+			nread = m_sockin[i]->readDatagram(datagram.data(), datagram.size());
+			if (nread > 0) {
+				datagram.resize(nread);
+				emit received(datagram, i);
+			}
+		}
+	}
+}
+
+#else
+
 // Get interface address from supplied name.
 bool qmidinetUdpDevice::get_address (
 	int sock, struct in_addr *inaddr, const char *ifname )
@@ -437,7 +634,7 @@ bool qmidinetUdpDevice::get_address (
 #if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 
 	struct ifreq ifr;
-	::strncpy(ifr.ifr_name, ifname, sizeof(ifr.ifr_name));
+	::strncpy(ifr.ifr_name, ifname, sizeof(ifr.ifr_name) - 1);
 
 	if (::ioctl(sock, SIOCGIFFLAGS, (char *) &ifr)) {
 		::perror("ioctl(SIOCGIFFLAGS)");
@@ -467,5 +664,7 @@ bool qmidinetUdpDevice::get_address (
 #endif	// !WIN32
 }
 
+#endif	// !CONFIG_IPV6
+
 
 // end of qmidinetUdpDevice.h
