@@ -1,7 +1,7 @@
 // qmidinetUdpDevice.h
 //
 /****************************************************************************
-   Copyright (C) 2010-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,18 +22,27 @@
 #ifndef __qmidinetUdpDevice_h
 #define __qmidinetUdpDevice_h
 
+#include "qmidinetAbout.h"
+
 #include <stdio.h>
 
+#if !defined(CONFIG_IPV6)
 #if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 #include <winsock.h>
 #else
 #include <arpa/inet.h>
 #include <net/if.h>
 #endif
+#endif	// !CONFIG_IPV6
 
 #include <QObject>
 #include <QString>
 
+#if defined(CONFIG_IPV6)
+#include <QUdpSocket>
+#include <QHostAddress>
+#endif
+
 
 //----------------------------------------------------------------------------
 // qmidinetUdpDevice -- Network interface device (UDP/IP).
@@ -45,7 +54,7 @@ class qmidinetUdpDevice : public QObject
 public:
 
 	// Constructor.
-	qmidinetUdpDevice(QObject *pParent = NULL);
+	qmidinetUdpDevice(QObject *pParent = nullptr);
 
 	// Destructor.
 	~qmidinetUdpDevice();
@@ -74,16 +83,36 @@ public slots:
 	// Receive data slot.
 	void receive(const QByteArray& data, int port);
 
+#if defined(CONFIG_IPV6)
+protected slots:
+
+	// Process incoming datagrams.
+	void readPendingDatagrams();
+
+#else
 protected:
 
 	// Get interface address from supplied name.
 	static bool get_address(int sock, struct in_addr *iaddr, const char *ifname);
 
+#endif	// !CONFIG_IPV6
+
 private:
 
 	// Instance variables,
 	int  m_nports;
 
+#if defined(CONFIG_IPV6)
+
+	QUdpSocket **m_sockin;
+	QUdpSocket **m_sockout;
+
+	QHostAddress m_udpaddr;
+
+	int *m_udpport;
+
+#else
+
 	int *m_sockin;
 	int *m_sockout;
 
@@ -92,6 +121,8 @@ private:
 	// Network receiver thread.
 	class qmidinetUdpDeviceThread *m_pRecvThread;
 
+#endif	// !CONFIG_IPV6
+
 	// Kind-of singleton reference.
 	static qmidinetUdpDevice *g_pDevice;
 };
